@@ -122,14 +122,6 @@ IGRAPH_EXPORT igraph_error_t igraph_eigenvector_centrality(const igraph_t *graph
                                                 const igraph_vector_t *weights,
                                                 igraph_arpack_options_t *options);
 
-IGRAPH_EXPORT igraph_error_t igraph_hub_score(const igraph_t *graph, igraph_vector_t *vector,
-                                   igraph_real_t *value, igraph_bool_t scale,
-                                   const igraph_vector_t *weights,
-                                   igraph_arpack_options_t *options);
-IGRAPH_EXPORT igraph_error_t igraph_authority_score(const igraph_t *graph, igraph_vector_t *vector,
-                                         igraph_real_t *value, igraph_bool_t scale,
-                                         const igraph_vector_t *weights,
-                                         igraph_arpack_options_t *options);
 IGRAPH_EXPORT igraph_error_t igraph_hub_and_authority_scores(const igraph_t *graph, igraph_vector_t *hub_vector,
                                          igraph_vector_t *authority_vector,
                                          igraph_real_t *value, igraph_bool_t scale,
@@ -142,7 +134,7 @@ IGRAPH_EXPORT igraph_error_t igraph_constraint(const igraph_t *graph, igraph_vec
 IGRAPH_EXPORT igraph_error_t igraph_convergence_degree(const igraph_t *graph, igraph_vector_t *result,
                                             igraph_vector_t *ins, igraph_vector_t *outs);
 
-IGRAPH_EXPORT igraph_real_t igraph_centralization(const igraph_vector_t *scores,
+IGRAPH_EXPORT IGRAPH_FUNCATTR_PURE igraph_real_t igraph_centralization(const igraph_vector_t *scores,
                                                   igraph_real_t theoretical_max,
                                                   igraph_bool_t normalized);
 
@@ -196,6 +188,17 @@ IGRAPH_EXPORT igraph_error_t igraph_centralization_eigenvector_centrality_tmax(
     igraph_bool_t scale,
     igraph_real_t *res);
 
+/* Deprecated functions: */
+
+IGRAPH_DEPRECATED IGRAPH_EXPORT igraph_error_t igraph_hub_score(const igraph_t *graph, igraph_vector_t *vector,
+                                   igraph_real_t *value, igraph_bool_t scale,
+                                   const igraph_vector_t *weights,
+                                   igraph_arpack_options_t *options);
+IGRAPH_DEPRECATED IGRAPH_EXPORT igraph_error_t igraph_authority_score(const igraph_t *graph, igraph_vector_t *vector,
+                                         igraph_real_t *value, igraph_bool_t scale,
+                                         const igraph_vector_t *weights,
+                                         igraph_arpack_options_t *options);
+
 __END_DECLS
 
 #endif
